@@ -122,7 +122,7 @@ builtins_isinstance = builtins.isinstance
 
 def mysmallisinstance(obj1: Any, obj2) -> bool:
     """Will return True when testing whether a TransparentPath is a str (required to use open(TransparentPath()))
-    or a TransparentPath, and False in every other cases (even pathlib.Path). """
+    or a TransparentPath, and False in every other cases (even pathlib.Path)."""
 
     if type(obj1) == TransparentPath:
         if obj2 == TransparentPath or obj2 == str:
@@ -230,7 +230,7 @@ def treat_remote_refix(path: Union[Path, TransparentPath, str], bucket: str) ->
                 "is specified with bucket= or if TransparentPath already has been set to use a specified bucket"
                 "with set_global_fs"
             )
-        path = str(path).replace(TransparentPath.remote_prefix, "")
+        path = str(path).replace(TransparentPath.remote_prefix, "", 1)
 
     else:
         bucket_from_path = splitted[1].split("/")[0]
@@ -242,7 +242,10 @@ def treat_remote_refix(path: Union[Path, TransparentPath, str], bucket: str) ->
                 )
         else:
             bucket = bucket_from_path
-        path = str(path).replace(TransparentPath.remote_prefix, "").replace(bucket_from_path, "")
+
+        path = str(path).replace(TransparentPath.remote_prefix, "", 1)
+        if path.startswith(bucket_from_path) or (len(path) > 0 and path[1:].startswith(bucket_from_path)):
+            path = path.replace(bucket_from_path, "", 1)
         if path.startswith("/"):
             path = path[1:]
     return path, bucket
@@ -358,7 +361,13 @@ def get_buckets(fs: gcsfs.GCSFileSystem) -> List[str]:
         next_page_token = page.get("nextPageToken", None)
 
         while next_page_token is not None:
-            page = fs.call("GET", "b/", project=fs.project, pageToken=next_page_token, json_out=True,)
+            page = fs.call(
+                "GET",
+                "b/",
+                project=fs.project,
+                pageToken=next_page_token,
+                json_out=True,
+            )
 
             assert page["kind"] == "storage#buckets"
             items.extend(page.get("items", []))
@@ -664,7 +673,7 @@ class TransparentPath(os.PathLike):  # noqa : F811
 
     @classmethod
     def show_state(cls):
-        """ Prints the state of the TransparentPath class """
+        """Prints the state of the TransparentPath class"""
         print("remote_prefix: ", cls.remote_prefix)
         print("fss: ", cls.fss)
         print("buckets_in_project: ", cls.buckets_in_project)
@@ -687,7 +696,7 @@ class TransparentPath(os.PathLike):  # noqa : F811
 
     @classmethod
     def get_state(cls) -> dict:
-        """ Returns the state of the TransparentPath class in a dictionnary"""
+        """Returns the state of the TransparentPath class in a dictionnary"""
         state = {
             "remote_prefix": cls.remote_prefix,
             "fss": cls.fss,
@@ -763,7 +772,10 @@ class TransparentPath(os.PathLike):  # noqa : F811
 
     translations = {
         "mkdir": MultiMethodTranslator(
-            "mkdir", ["local", "gcs"], ["mkdir", "self._do_nothing"], [{"parents": "create_parents"}, {"parents": ""}],
+            "mkdir",
+            ["local", "gcs"],
+            ["mkdir", "self._do_nothing"],
+            [{"parents": "create_parents"}, {"parents": ""}],
         ),
     }
 
@@ -992,8 +1004,8 @@ class TransparentPath(os.PathLike):  # noqa : F811
                     self.__path = Path(self.bucket) / self.__path
             else:
                 self.__path = Path(self.bucket) / self.__path
-            if len(self.__path.parts) > 1 and self.bucket in self.__path.parts[1:]:
-                raise TPValueError("You should never use your bucket name as a directory or file name.")
+            # if len(self.__path.parts) > 1 and self.bucket in self.__path.parts[1:]:
+            #     raise TPValueError("You should never use your bucket name as a directory or file name.")
 
         if self.when_checked["created"] and not self.nocheck:
             self._check_multiplicity()
@@ -1140,8 +1152,8 @@ class TransparentPath(os.PathLike):  # noqa : F811
     def __hash__(self) -> int:
         """Uniaue hash number.
 
-         Two TransarentPath will have a same hash number if their fspath are the same and fs_kind (which will inlude
-         the project name if remote) are the same."""
+        Two TransarentPath will have a same hash number if their fspath are the same and fs_kind (which will inlude
+        the project name if remote) are the same."""
         hash_number = int.from_bytes((self.fs_kind + self.__fspath__()).encode(), "little") + int.from_bytes(
             self.fs_kind.encode(), "little"
         )
@@ -1271,7 +1283,7 @@ class TransparentPath(os.PathLike):  # noqa : F811
     def _obj_missing(self, obj_name: str, kind: str, *args, **kwargs) -> Any:
         """Method to catch any call to a method/attribute missing from the class.
         Tries to call the object on the class's FileSystem object or the instance's self.path (a pathlib.Path object) if
-        FileSystem is local 
+        FileSystem is local
 
 
         Parameters
@@ -1350,8 +1362,8 @@ class TransparentPath(os.PathLike):  # noqa : F811
 
     def _transform_path(self, method_name: str, *args: Tuple) -> Tuple:
         """
-        File system methods take self.path as first argument, so add its absolute path as first argument of args. 
-        Some, like ls or glob, are given a relative path to append to self.path, so we need to change the first 
+        File system methods take self.path as first argument, so add its absolute path as first argument of args.
+        Some, like ls or glob, are given a relative path to append to self.path, so we need to change the first
         element of args from args[0] to self.path / args[0]
 
         Parameters
@@ -1428,7 +1440,7 @@ class TransparentPath(os.PathLike):  # noqa : F811
         self.last_check = time()
 
     def _do_nothing(self) -> None:
-        """ does nothing (you don't say) """
+        """does nothing (you don't say)"""
         pass
 
     # ////////////// #
@@ -1488,17 +1500,10 @@ class TransparentPath(os.PathLike):  # noqa : F811
         return self.is_file()
 
     def isdir(self, *args, **kwargs):
-        return self.is_dir(*args, **kwargs)
+        return self.is_dir()
 
-    def is_dir(self, exist: bool = False, **kwargs) -> bool:
-        """Check if self is a directory
-
-
-        Parameters
-        ----------
-        exist: bool
-            If False and if using GCS, is_dir() returns True if the directory does not exist and no file with
-            the same path exist. Otherwise, only returns True if the directory really exists (Default value = False).
+    def is_dir(self, *args, **kwargs) -> bool:
+        """Check if self is a directory.
 
 
         Returns
@@ -1509,7 +1514,7 @@ class TransparentPath(os.PathLike):  # noqa : F811
         if self.fs_kind == "local":
             return self.__path.is_dir()
         else:
-            if exist and not self.exists():
+            if not self.exists():
                 return False
             if self.is_file():
                 return False
@@ -1576,7 +1581,7 @@ class TransparentPath(os.PathLike):  # noqa : F811
         recursive = kwargs.get("recursive", False)
 
         if recursive:
-            if not self.is_dir(exist=True):
+            if not self.is_dir():
                 # ...but self points to something that is not a directory!
                 if self.exists():
                     # Delete anyway
@@ -1605,7 +1610,7 @@ class TransparentPath(os.PathLike):  # noqa : F811
         # Asked to remove a file...
         else:
             # ...but self points to a directory!
-            if self.is_dir(exist=True):
+            if self.is_dir():
                 # Delete anyway
                 if ignore_kind:
                     kwargs["recursive"] = True
@@ -1650,7 +1655,9 @@ class TransparentPath(os.PathLike):  # noqa : F811
         """
         self.rm(absent=absent, ignore_kind=ignore_kind, recursive=True)
 
-    def glob(self, wildcard: str = "*", fast: bool = False) -> Iterator[TransparentPath]:
+    def glob(
+        self, wildcard: str = "*", fast: bool = False, i_am_sure_i_am_a_dir: bool = False
+    ) -> Iterator[TransparentPath]:
         """Returns a list of TransparentPath matching the wildcard pattern.
 
         By default, the wildcard is '*'. It means 'thepath/*', so will glob in the directory.
@@ -1663,6 +1670,8 @@ class TransparentPath(os.PathLike):  # noqa : F811
         fast: bool
             If True, does not check multiplicity when converting output paths to TransparentPath, significantly
             speeding up the process (Default value = False)
+        i_am_sure_i_am_a_dir: bool
+            If True, will not check that self points to a directory. Saves time.
 
 
         Returns
@@ -1672,8 +1681,9 @@ class TransparentPath(os.PathLike):  # noqa : F811
 
         """
 
-        if not self.is_dir(exist=True):
-            raise TPNotADirectoryError("The path must be a directory if you want to glob in it")
+        if not i_am_sure_i_am_a_dir:
+            if not self.is_dir():
+                raise TPNotADirectoryError("The path must be a directory if you want to glob in it")
 
         if wildcard.startswith("/") or wildcard.startswith("\\"):
             wildcard = wildcard[1:]
@@ -1683,10 +1693,16 @@ class TransparentPath(os.PathLike):  # noqa : F811
 
         path_to_glob = (self.__path / wildcard).__fspath__()
 
-        if fast:
-            to_ret = map(self._cast_fast, self.fs.glob(path_to_glob))
-        else:
-            to_ret = map(self._cast_slow, self.fs.glob(path_to_glob))
+        try:
+            if fast:
+                to_ret = map(self._cast_fast, self.fs.glob(path_to_glob))
+            else:
+                to_ret = map(self._cast_slow, self.fs.glob(path_to_glob))
+        except TypeError as e:
+            if "list indices must be integers or slices, not str" in str(e):
+                to_ret = []
+            else:
+                raise e
         return to_ret
 
     def with_suffix(self, suffix: str) -> TransparentPath:
@@ -1719,7 +1735,7 @@ class TransparentPath(os.PathLike):  # noqa : F811
         )
 
     def ls(self, path_to_ls: str = "", fast: bool = False) -> Iterator[TransparentPath]:
-        """ Unlike glob, if on GCS, will also see directories.
+        """Unlike glob, if on GCS, will also see directories.
 
 
         Parameters
@@ -1741,7 +1757,7 @@ class TransparentPath(os.PathLike):  # noqa : F811
         if isinstance(path_to_ls, TransparentPath):
             raise TypeError("Can not use a TransparentPath as a argument of ls() : TransparentPath are all absolute")
 
-        if not self.is_dir(exist=True):
+        if not self.is_dir():
             raise TPNotADirectoryError("The path must be a directory if you want to ls in it")
 
         if fast:
@@ -1752,12 +1768,12 @@ class TransparentPath(os.PathLike):  # noqa : F811
 
     def cd(self, path: Optional[str] = None) -> None:
         """cd-like command. Works inplace
-        
-        Will collapse double-dots ('..'), so not compatible with symlinks. If path is absolute (starts with '/' or 
-        bucket name or is empty), will return a path starting from root directory if FileSystem is local, from bucket 
-        if it is GCS. If passing None or "" , will have the same effect than "/" on GCS, will return the current 
-        working directory on local. If passing ".", will return a path at the location of self. Will raise an error 
-        if trying to access a path before root or bucket. 
+
+        Will collapse double-dots ('..'), so not compatible with symlinks. If path is absolute (starts with '/' or
+        bucket name or is empty), will return a path starting from root directory if FileSystem is local, from bucket
+        if it is GCS. If passing None or "" , will have the same effect than "/" on GCS, will return the current
+        working directory on local. If passing ".", will return a path at the location of self. Will raise an error
+        if trying to access a path before root or bucket.
 
 
         Parameters
@@ -1778,7 +1794,7 @@ class TransparentPath(os.PathLike):  # noqa : F811
         if not isinstance(path, str) or isinstance(path, TransparentPath):
             raise TPTypeError("Can only pass a string to TransparentPath's cd method")
 
-        path = path.replace(TransparentPath.remote_prefix, "")
+        path = path.replace(TransparentPath.remote_prefix, "", 1)
 
         if "gcs" in self.fs_kind and str(path) == self.bucket or path == "" or path == "/":
             self.__path = Path(self.bucket)
@@ -2148,7 +2164,14 @@ class TransparentPath(os.PathLike):  # noqa : F811
         elif self.when_updated["created"] and not self.notupdatecache:  # Else, because called by check_multiplicity
             self._update_cache()
 
-    def read(self, *args, get_obj: bool = False, use_pandas: bool = False, use_dask: bool = False, **kwargs,) -> Any:
+    def read(
+        self,
+        *args,
+        get_obj: bool = False,
+        use_pandas: bool = False,
+        use_dask: bool = False,
+        **kwargs,
+    ) -> Any:
         """Method used to read the content of the file located at self
 
         Will raise FileNotFound error if there is no file. Calls a specific method to read self based on the suffix
@@ -2302,39 +2325,66 @@ class TransparentPath(os.PathLike):  # noqa : F811
             args = args[1:]
 
         if self.suffix == ".csv":
-            ret = self.to_csv(data=data, overwrite=overwrite, present=present, **kwargs,)
+            ret = self.to_csv(
+                data=data,
+                overwrite=overwrite,
+                present=present,
+                **kwargs,
+            )
             if ret is not None:
                 # To skip the assert at the end of the function. Indeed if something is returned it means we used
                 # Dask, which will have written files with a different name than self, so the assert would fail.
                 return
         elif self.suffix == ".parquet":
             self.to_parquet(
-                data=data, overwrite=overwrite, present=present, **kwargs,
+                data=data,
+                overwrite=overwrite,
+                present=present,
+                **kwargs,
             )
             if "dask" in str(type(data)):
                 # noinspection PyUnresolvedReferences
                 assert self.with_suffix("").is_dir(exist=True)
                 return
         elif self.suffix == ".hdf5" or self.suffix == ".h5":
-            ret = self.to_hdf5(data=data, set_name=set_name, use_pandas=use_pandas, **kwargs,)
+            ret = self.to_hdf5(
+                data=data,
+                set_name=set_name,
+                use_pandas=use_pandas,
+                **kwargs,
+            )
             if ret is not None:
                 # will not cache the changes for they will happen outside TransparentPath
                 return ret
         elif self.suffix == ".json":
             self.to_json(
-                data=data, overwrite=overwrite, present=present, **kwargs,
+                data=data,
+                overwrite=overwrite,
+                present=present,
+                **kwargs,
             )
         elif self.suffix == ".txt":
             self.write_stuff(
-                *args, data=data, overwrite=overwrite, present=present, **kwargs,
+                *args,
+                data=data,
+                overwrite=overwrite,
+                present=present,
+                **kwargs,
             )
         elif self.suffix in [".xlsx", ".xls", ".xlsm"]:
             self.to_excel(
-                data=data, overwrite=overwrite, present=present, **kwargs,
+                data=data,
+                overwrite=overwrite,
+                present=present,
+                **kwargs,
             )
         else:
             self.write_bytes(
-                *args, data=data, overwrite=overwrite, present=present, **kwargs,
+                *args,
+                data=data,
+                overwrite=overwrite,
+                present=present,
+                **kwargs,
             )
         self.update_tpchache(data)
         assert self.is_file()
@@ -2503,6 +2553,14 @@ setattr(TransparentPath, "read_text", read_text)
 setattr(TransparentPath, "write_stuff", write_stuff)
 setattr(TransparentPath, "write_bytes", write_bytes)
 
+try:
+    # noinspection PyUnresolvedReferences
+    from transparentpath.io.joblib_load import overload_joblib_load
+
+    overload_joblib_load()
+except ImportError:
+    pass
+
 try:
     # noinspection PyUnresolvedReferences
     from transparentpath.io.json import read, write
